/*
   MyidePartitionInfo - base class for CHS and LBA partition infos

   Copyright (C) 2008 Matthias Reichl <hias@horus.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "MyidePartitionInfo.h"

MyidePartitionInfo::MyidePartitionInfo()
	: fOptionByte(0), fDriveBits(0)
{ }

MyidePartitionInfo::~MyidePartitionInfo()
{ }

const char* MyidePartitionInfo::DensityAsString(EDensity density, bool emulated_QD)
{
	switch (density) {
	case eSD: return "SD";
	case eDD: return "DD";
	case eQD: 
		if (emulated_QD) {
			return "qd";
		} else {
			return "QD";
		}
	default: return "??";
	}
}

bool MyidePartitionInfo::IsChsPartitionTable() const
{
	return false;
}

bool MyidePartitionInfo::IsLbaPartitionTable() const
{
	return false;
}

bool MyidePartitionInfo::IsValidSectorLength(unsigned int sector, EDensity density, unsigned int seclen)
{
	switch (density) {
	case eSD:
		return seclen == 128;
	case eDD:
		if (sector <= 3) {
			return seclen == 128;
		} else {
			return seclen == 256;
		}
	case eQD:
		return seclen == 512;
	default:
		return false;
	}
}
