#ifndef MYIDEPARTITIONINFO_H
#define MYIDEPARTITIONINFO_H

/*
   MyidePartitionInfo - base class for CHS and LBA partition infos

   Copyright (C) 2008 Matthias Reichl <hias@horus.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include "RefCounted.h"
#include "AtariDebug.h"
#include "AtrUtils.h"

class MyidePartitionInfo : public RefCounted {
public:
	MyidePartitionInfo();
	virtual ~MyidePartitionInfo();

	virtual bool ParsePartitionInfo(const unsigned char* buf) = 0;
	virtual bool CreatePartitionInfo(unsigned char* buf) const = 0;

	virtual bool IsChsPartitionTable() const;
	virtual bool IsLbaPartitionTable() const;

	virtual void PrintPartitionTable() const = 0;
	
	// partition functions
	virtual unsigned int GetNumberOfPartitions() const = 0;

	virtual bool IsActivePartition(unsigned int num) const = 0;
	virtual unsigned int GetPartitionSize(unsigned int num) const = 0;
	virtual EDensity GetPartitionDensity(unsigned int num) const = 0;

	virtual bool IsEmulatedQDPartition(unsigned int num) const = 0;

	virtual bool IsValidPartitionNumber(unsigned int partno) const = 0;
	virtual bool IsValidPartitionSector(unsigned int partno, unsigned int secno) const = 0;

	// returns absolute sector number
	virtual unsigned int GetPartitionSectorNumber(unsigned int partno, unsigned int sector) const = 0;

	// image functions
	virtual bool ImageSpaceEnabled() const = 0;
	virtual unsigned int GetNumberOfImageSlots() const = 0;
	virtual unsigned int GetSectorsPerImageSlot() const = 0;

	virtual bool IsValidImageSector(unsigned int secno) const = 0;

	// returns absolute sector number
	virtual unsigned int GetImageSectorNumber(unsigned int imageno, unsigned int sector) const = 0;
	virtual unsigned int GetImageInfoSectorNumber(unsigned int imageno) const = 0;

	bool IsValidSectorLength(unsigned int sector, EDensity density, unsigned int seclen);

	inline unsigned char GetOptionByte() const;
	inline unsigned char GetDriveBits() const;

	static const char* DensityAsString(EDensity density, bool emulated_QD = false);

	// identification old CHS / new LBA partition information
	enum {
		eOffsetDriveNumbersPartitionVersion = 4
	};
	enum {
		eLBAPartitionTableMagic_old = 0x10,	// old SDX LBA id
		eLBAPartitionTableMagic_0 = 0xcc,	// SDX LBA id at offset 0
		eLBAPartitionTableMagic_1 = 0xc2,	// SDX LBA id at offset 1
		eLBAPartitionTableMagic_2 = 0xc1	// SDX LBA id at offset 2
	};

protected:
	unsigned char fOptionByte;
	unsigned char fDriveBits;

	inline bool DriveIncludedInDriveBits(unsigned int driveno) const;

private:
};

inline unsigned char MyidePartitionInfo::GetOptionByte() const
{
	return fOptionByte;
}

inline unsigned char MyidePartitionInfo::GetDriveBits() const
{
	return fDriveBits;
}

inline bool MyidePartitionInfo::DriveIncludedInDriveBits(unsigned int driveno) const
{
	if (driveno < 1 || driveno > 8) {
		return false;
	}
	return fDriveBits & (1<<(driveno-1));
}


#endif
